#
# spec file for package droidcam
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           droidcam
Version:        1.9.0
Release:        1.11
Summary:        Program to turn a mobile device into a webcam
License:        GPL-2.0-or-later
URL:            https://www.dev47apps.com/droidcam/linux/
Source0:        https://github.com/aramg/droidcam/archive/v%{version}.tar.gz#/droidcam-%{version}.tar.gz
Source1:        README-v4l2loopback.md
# PATCH-FIX-OPENSUSE
Patch2:         0003-Hack-backwards-compatibility-for-TurboJPEG-2.0.0.patch
# PATCH-FIX-OPENSUSE
Patch3:         0001-Use-icon-installed-to-theme-directory.patch
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libswscale)
# libusbmuxd 2.0.2 provides libusbmuxd-2.0, while 1.x/2.0.1 provide libusbmuxd
# BuildRequires:  pkgconfig(libusbmuxd-2.0)
BuildRequires:  libusbmuxd-devel
BuildRequires:  pkgconfig(speex)
Requires:       hicolor-icon-theme >= 0.17
Requires:       kmod(v4l2loopback.ko)
# USB connection uses adb for Android, other
# options are usbmuxd (iOS) or Wifi
Recommends:     adb

%description
This program turns a mobile device into a webcam.

It can be used with chat programs like Skype, Zoom, Teams, or with
live streaming programs like OBS.

%package cli
Summary:        Command line client for droidcam
Requires:       kmod(v4l2loopback.ko)
Recommends:     adb

%description cli
This program turns a mobile device into a webcam.

It can be used with chat programs like Skype, Zoom, Teams, or with
live streaming programs like OBS.

%prep
%autosetup -p1

%build
export USBMUXDLIBS="`pkg-config --silence-errors --libs libusbmuxd-2.0 || pkg-config --silence-errors --libs libusbmuxd`"
# CC is used for CXXFLAGS
%make_build JPEG="-lturbojpeg" USBMUXD=${USBMUXDLIBS} CFLAGS="%{optflags}" droidcam-cli
%make_build JPEG="-lturbojpeg" USBMUXD=${USBMUXDLIBS} CFLAGS="%{optflags}" droidcam

%install
install -D -m 755 -t %{buildroot}%{_bindir} droidcam-cli
install -D -m 755 -t %{buildroot}%{_bindir} droidcam
install -D -m 755 icon2.png %{buildroot}%{_datadir}/icons/hicolor/96x96/apps/droidcam.png
%suse_update_desktop_file -c droidcam droidcam "Virtual Webcam" droidcam droidcam Multimedia Video GTK Utility AudioVideo
cp %{S:1} ./

%files
%license LICENSE
%doc README-v4l2loopback.md
%{_bindir}/droidcam
%{_datadir}/icons/hicolor/*/apps/droidcam.png
%{_datadir}/applications/droidcam.desktop

%files cli
%license LICENSE
%doc README-v4l2loopback.md
%{_bindir}/droidcam-cli

%changelog
* Fri Apr  7 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.9.0
  * Increase the socket timeout, extra logging
  * Fixup a/v/batt syncing
  * Fix the White-Balance menu
  * Fix battery value parsing
  * Support ayatana-appindicator
  * Continue trying when setting audio hwparams fails
* Mon May 16 2022 Grover Chou <groverchout@opensuse.org>
- Update to version 1.8.2
  * Bugfix: Prevent UI alerts when connection is stopped abruptly. #210
- Update to version 1.8.1
  * Added -vflip/-hflip options to droidcam-cli
- Update to version 1.8.0
  * Fix for iOS USB connections dropping instantly (via #184)
  * Code updates (via #184)
  * Binaries now go into /usr/local/bin instead of /usr/bin, which is
    more "correct" for non-packaged software
  * Add battery-level check and label
  * Add flag that allows other programs (eg. ffmpeg) to use the v4l2-dc
    device
- Update to version 1.7.3
  * Bring back app-indicator by popular demand (#159).
- Update to version 1.7.2
  * GUI client saves + restores horizontal and vertical flip changes
  * GUI client: Exposure lock and white-balance controls
  * Update keyboard accelerators, hopefully fix the numpad plus/minus
    shortcuts for all keyboards
  * CLI client: -nocontrols flag to facilitate "headless mode" (#143)
- Update to version 1.7.1
  * Dropped 'appindicator' (systray icon) support as this library is
    deprecated and no longer works (at least on Debian).
- Updated patches:
  * 0001-Use-icon-installed-to-theme-directory.patch
  * 0003-Hack-backwards-compatibility-for-TurboJPEG-2.0.0.patch
* Mon Feb  8 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.7
  * Added 'Vertical Flip' option. (original PR: #120)
  * Added Gnome desktop entry. (original PR: #127)
  * GUI client will show a warning when closing with active
    connection.
  * Added -dev command line option, to use a specific video device
    instead of auto-discovery.
- Update to version 1.6
  * Added support for the regular v4l2loopback module
    (Original pr #105)
  * Fixed bug with server mode not using the port value correctly
    in the GUI
  * Fixed bug when connecting to iOS device via USB (#97)
- Fix failing build due to renamed libusbmusd pkgconfig file.
- Drop upstreamed v4l2loopback patches:
  * 0001-Enhance-compatibility-with-upstream-v4l2loopback-dri.patch
  * 0002-Accept-upstream-v4l2loopback-driver-as-device.patch
- Rebased patches:
  * 0001-Use-icon-installed-to-theme-directory.patch
  * 0003-Hack-backwards-compatibility-for-TurboJPEG-2.0.0.patch
* Tue Oct  6 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.5
  * AppIndicator support
  * Portrait mode and flip support
- Add README-v4l2loopback.md, referring to v4l2loopback-ctl for
  configuration
- Add 0001-Use-icon-installed-to-theme-directory.patch
- Skip EXIF marker handling in JPEG transform on Leap 15.x, update
  0003-Hack-backwards-compatibility-for-TurboJPEG-2.0.0.patch
* Sun Jul 12 2020 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for descriptions.
* Fri Jul 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Initial package version 1.4
- Add two patches to make it work with the upstream v4l2loopback driver:
  * 0001-Enhance-compatibility-with-upstream-v4l2loopback-dri.patch
  * 0002-Accept-upstream-v4l2loopback-driver-as-device.patch
- Add compatibility for TurboJPEG version in Leap 15.x
  * 0003-Hack-backwards-compatibility-for-TurboJPEG-2.0.0.patch
